# Aorta-Sirius

The Global Python SDK for the Central Finite Curve

[![codecov](https://codecov.io/gh/kontinuum-investments/Aorta-Sirius/branch/production/graph/badge.svg?token=TYY4X666XE)](https://codecov.io/gh/kontinuum-investments/Aorta-Sirius)

# Installation

## Required Environmental Variables

- `APPLICATION_NAME` _(Used as the default Discord Server Name)_
- `DISCORD_BOT_TOKEN`
- `SENTRY_URL`
- `WISE_SANDBOX_ACCOUNT_API_KEY` _(for development environment)_
- `WISE_PRIMARY_ACCOUNT_API_KEY` _(for production environment)_
- `WISE_SECONDARY_ACCOUNT_API_KEY` _(for production environment)_
- `MONGO_DB_CONNECTION_STRING`

## Development

## Required Organization Secrets

- `SENTRY_URL`
- `WISE_SANDBOX_ACCOUNT_API_KEY`

## Required Repository Secrets

- `CODECOV_TOKEN`
- `PYPI_ACCESS_TOKEN`
- `QODANA_TOKEN`

## Required Repository Variables

- `APPLICATION_NAME`